@@ -666,9 +666,9 @@ class Test_format_exception(unittest.TestCase):
             s = self._callFUT(False)
         lines = s.splitlines()[-3:]
         self.assertEqual(lines[0], '    syntax error')
-        # PyPy has a shorter prefix
-        self.assertTrue(lines[1].endswith('    ^'))
-        self.assertEqual(lines[2], 'SyntaxError: invalid syntax')
+        self.assertIn('    ^', lines[1])
+        self.assertTrue(lines[2].startswith('SyntaxError: invalid syntax'),
+                        lines[2])
 
     def test_traceback_info_non_ascii(self):
         __traceback_info__ = u"Have a Snowman: \u2603"
